<?php
	/*
	* GMapFP Component Google Map for Joomla! 3.x
	* Version J3.124pro
	* Creation date: Mai 2020
	* Author: Fabrice4821 - www.gmapfp.org
	* Author email: webmaster@gmapfp.org
	* License GNU/GPL
	*/

defined('_JEXEC') or die;

	jimport('joomla.filesystem.file');
	jimport('joomla.log.log');
	jimport('joomla.client.helper');


class GMapFPControllerGMapFP extends GMapFPController
{
	function __construct($config = array())
	{
		JLog::addLogger(
			array(
				//Sets file name
				'text_file' => 'com_gmapfp.log.php'
			),
			//Sets all JLog messages to be set to the file
			JLog::ALL,
			//Chooses a category name
			'com_gmapfp'
		);
		
		$this->option = "com_gmapfp";
		
		parent::__construct();

		// Register Extra tasks
		$this->registerTask( 'add', 'edit' );
		$this->registerTask( 'unpublish', 	'publish');
		$this->registerTask( 'unfeatured', 	'featured');
	}

	function edit()
	{
		if (!JFactory::getUser()->authorise('core.manage', 'com_gmapfp'))
			return JFactory::getApplication()->enqueueMessage(JText::_('JERROR_ALERTNOAUTHOR'), 'error');

		$model = $this->getModel('gmapfp');
		$cid = JRequest::getVar('cid', array(0));
		$recordId = $cid[0];
		//$context = "$this->option.edit.$this->context";

		// Access check.
		if (!JFactory::getUser()->authorise('core.edit', 'com_gmapfp'))
		{
			$this->setError(JText::_('JLIB_APPLICATION_ERROR_EDIT_NOT_PERMITTED'));
			$this->setMessage($this->getError(), 'error');

			$this->setRedirect(JRoute::_('index.php?option=com_gmapfp&controller=gmapfp&task=view', false));
			return false;
		}

		if (!$model->checkout($recordId))
		{
			// Check-out failed, display a notice but allow the user to see the record.
			$this->setError(JText::sprintf('JLIB_APPLICATION_ERROR_CHECKOUT_FAILED', $model->getError()));
			$this->setMessage($this->getError(), 'error');

			$this->setRedirect(JRoute::_('index.php?option=com_gmapfp&controller=gmapfp&task=view', false));
			return false;
		}
		else
		{
			$this->input->set( 'view', 'gmapfp' );
			$this->input->set( 'layout', 'edit'  );
			$this->input->set('hidemainmenu', 1);
	
			parent::display();
		}
	}

	function view()
	{
		if (!JFactory::getUser()->authorise('core.manage', 'com_gmapfp'))
			return JFactory::getApplication()->enqueueMessage(JText::_('JERROR_ALERTNOAUTHOR'), 'error');

		$this->input->set( 'view', 'gmapfps' );
		$this->input->set( 'layout', 'default'  );

		parent::display();
	}

	function galerie()
	{
		if (!JFactory::getUser()->authorise('core.manage', 'com_gmapfp'))
			return JFactory::getApplication()->enqueueMessage(JText::_('JERROR_ALERTNOAUTHOR'), 'error');

		$this->input->set( 'view', 'gmapfp' );
		$this->input->set( 'layout', 'medialist'  );

		parent::display();
	}

	function infos()
	{
		if (!JFactory::getUser()->authorise('core.manage', 'com_gmapfp'))
			return JFactory::getApplication()->enqueueMessage(JText::_('JERROR_ALERTNOAUTHOR'), 'error');

		$this->input->set( 'view', 'gmapfp' );
		$this->input->set( 'layout', 'infos_form'  );

		parent::display();
	}

	function save()
	{
		if (!JFactory::getUser()->authorise('core.manage', 'com_gmapfp') or !JFactory::getUser()->authorise('core.create', 'com_gmapfp'))
			return JFactory::getApplication()->enqueueMessage(JText::_('JERROR_ALERTNOAUTHOR'), 'error');

		$post	= JRequest::get('post');
		$model = $this->getModel('gmapfp');
		$returnid=$model->store($post);
		if ($returnid>0) {
			$this->checkin($returnid);
			$msg = JText::_( 'GMAPFP_SAVED' );
		} else {
			$msg = JText::_( 'GMAPFP_SAVED_ERROR' );
		}

		$link = 'index.php?option=com_gmapfp&controller=gmapfp&task=view';
		// Check the table in so it can be edited.... we are done with it anyway
		$this->setRedirect($link, $msg);
	}
	
	function save2new()
	{
		if (!JFactory::getUser()->authorise('core.manage', 'com_gmapfp') or !JFactory::getUser()->authorise('core.create', 'com_gmapfp'))
			return JFactory::getApplication()->enqueueMessage(JText::_('JERROR_ALERTNOAUTHOR'), 'error');

		$post	= JRequest::get('post');
		$model = $this->getModel('gmapfp');
		$returnid=$model->store($post);
		if ($returnid>0) {
			$this->checkin($returnid);
			$msg = JText::_( 'GMAPFP_SAVED' );
		} else {
			$msg = JText::_( 'GMAPFP_SAVED_ERROR' );
		}

		$link = 'index.php?option=com_gmapfp&controller=gmapfp&task=edit';
		// Check the table in so it can be edited.... we are done with it anyway
		$this->setRedirect($link, $msg);
	}

	function apply()
	{
		if (!JFactory::getUser()->authorise('core.manage', 'com_gmapfp') or !(JFactory::getUser()->authorise('core.edit', 'com_gmapfp') and JFactory::getUser()->authorise('core.edit.own', 'com_gmapfp')))
			return JFactory::getApplication()->enqueueMessage(JText::_('JERROR_ALERTNOAUTHOR'), 'error');

		$post	= JRequest::get('post');
		$model = $this->getModel('gmapfp');
		$returnid=$model->store($post);
		if ($returnid>0) {
			$msg = JText::_( 'GMAPFP_SAVED' );
		} else {
			$msg = JText::_( 'GMAPFP_SAVED_ERROR' );
		}

		$link = 'index.php?option=com_gmapfp&controller=gmapfp&task=edit&cid[]='.(int)$returnid;
		// Check the table in so it can be edited.... we are done with it anyway
		$this->setRedirect($link, $msg);
	}

	function remove()
	{
		if (!JFactory::getUser()->authorise('core.manage', 'com_gmapfp') or !JFactory::getUser()->authorise('core.delete', 'com_gmapfp'))
			return JFactory::getApplication()->enqueueMessage(JText::_('JERROR_ALERTNOAUTHOR'), 'error');

		$model = $this->getModel('gmapfp');
		if(!$model->delete()) {
			$msg = JText::_( 'Error: One or more GMapFPs could not be Deleted' );
		} else {
			$msg = JText::_( 'GMapFP(s) Deleted' );
		}
		$this->setRedirect( 'index.php?option=com_gmapfp&controller=gmapfp&task=view', $msg );
	}

	function publish()
	{
		$dispatcher = \JEventDispatcher::getInstance();
		// Include the plugins for the change of state event.
		\JPluginHelper::importPlugin('content');
		
		
		if (!JFactory::getUser()->authorise('core.manage', 'com_gmapfp') or !JFactory::getUser()->authorise('core.edit.state', 'com_gmapfp'))
			return JFactory::getApplication()->enqueueMessage(JText::_('JERROR_ALERTNOAUTHOR'), 'error');

		$this->setRedirect( 'index.php?option=com_gmapfp&controller=gmapfp&task=view' );

		// Initialize variables
		$db			= JFactory::getDBO();
		$user		= JFactory::getUser();
		$pks		= JRequest::getVar( 'cid', array(), 'post', 'array' );
		$task		= JRequest::getCmd( 'task' );
		$value	= ($task == 'publish');
		$n			= count( $pks );

		if (empty( $pks )) {
			return JFactory::getApplication()->enqueueMessage(JText::_('No items selected'), 'error');
		}

		JArrayHelper::toInteger( $pks );
		$cids = implode( ',', $pks );

		$query = 'UPDATE #__gmapfp'
		. ' SET published = ' . (int) $value
		. ' WHERE id IN ( '. $cids .' )'
		;
		$db->setQuery( $query );
		if (!$db->query()) {
			return JError::raiseWarning( 500, $db->stderr() );
		}
		if ($n>1)
			$this->setMessage( JText::sprintf( $value ? 'GMAPFP_ELEMENTS_N_ITEMS_PUBLISHED' : 'GMAPFP_ELEMENTS_N_ITEMS_UNPUBLISHED', $n ) );
		else
			$this->setMessage( JText::sprintf( $value ? 'GMAPFP_ELEMENTS_N_ITEMS_PUBLISHED_1' : 'GMAPFP_ELEMENTS_N_ITEMS_UNPUBLISHED_1', $n ) );

		$context = $this->option . '.' . $this->name;
		// Trigger the change state event.
		$result = $dispatcher->trigger('onContentChangeState', array($context, $pks, $value));
		
	}

	function featured()
	{
		if (!JFactory::getUser()->authorise('core.manage', 'com_gmapfp') or !JFactory::getUser()->authorise('core.edit.state', 'com_gmapfp'))
			return JFactory::getApplication()->enqueueMessage(JText::_('JERROR_ALERTNOAUTHOR'), 'error');

		$this->setRedirect( 'index.php?option=com_gmapfp&controller=gmapfp&task=view' );

		// Initialize variables
		$db			= JFactory::getDBO();
		$user		= JFactory::getUser();
		$cid		= JRequest::getVar( 'cid', array(), 'post', 'array' );
		$task		= JRequest::getCmd( 'task' );
		$featured	= ($task == 'featured');
		$n			= count( $cid );

		if (empty( $cid )) {
			return JFactory::getApplication()->enqueueMessage(JText::_('No items selected'), 'error');
		}

		JArrayHelper::toInteger( $cid );
		$cids = implode( ',', $cid );

		$query = 'UPDATE #__gmapfp'
		. ' SET featured = ' . (int) $featured
		. ' WHERE id IN ( '. $cids .' )'
		;
		$db->setQuery( $query );
		if (!$db->query()) {
			return JError::raiseWarning( 500, $db->stderr() );
		}
		if ($n>1)
			$this->setMessage( JText::sprintf( $featured ? 'GMAPFP_ELEMENTS_N_ITEMS_PUBLISHED' : 'GMAPFP_ELEMENTS_N_ITEMS_UNPUBLISHED', $n ) );
		else
			$this->setMessage( JText::sprintf( $featured ? 'GMAPFP_ELEMENTS_N_ITEMS_PUBLISHED_1' : 'GMAPFP_ELEMENTS_N_ITEMS_UNPUBLISHED_1', $n ) );

	}

	function _modif_access($access)
	{
		if (!JFactory::getUser()->authorise('core.manage', 'com_gmapfp') or !(JFactory::getUser()->authorise('core.edit', 'com_gmapfp') and JFactory::getUser()->authorise('core.edit.own', 'com_gmapfp')))
			return JFactory::getApplication()->enqueueMessage(JText::_('JERROR_ALERTNOAUTHOR'), 'error');

		$this->setRedirect( 'index.php?option=com_gmapfp&controller=gmapfp&task=view' );

		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );

		// Initialize variables
		$db		= JFactory::getDBO();

		$cid	= JRequest::getVar( 'cid', array(0), 'post', 'array' );
		$cid	= $cid[0];

		$query = 'UPDATE #__gmapfp'
		. ' SET access = ' . (int) $access
		. ' WHERE id IN ( '. $cid .' )'
		;
		$db->setQuery( $query );
		if (!$db->query()) {
			return JError::raiseWarning( 500, $db->stderr() );
		}
	}

	function accesspublic()
	{
		$this->_modif_access(0);
	}
	
	function accessregistered()
	{
		$this->_modif_access(1);
	}
	
	function accessspecial()
	{
		$this->_modif_access(2);
	}
	
	function copy()
	{
		if (!JFactory::getUser()->authorise('core.manage', 'com_gmapfp') or !JFactory::getUser()->authorise('core.create', 'com_gmapfp'))
			return JFactory::getApplication()->enqueueMessage(JText::_('JERROR_ALERTNOAUTHOR'), 'error');

		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );

		$this->setRedirect( 'index.php?option=com_gmapfp&controller=gmapfp&task=view' );

		$cid	= JRequest::getVar( 'cid', null, 'post', 'array' );
		$db		= JFactory::getDBO();
		$model  = $this->getModel('gmapfp');
		$table	= $model->getTable('GMapFP', 'GMapFPTable');
		$user	= JFactory::getUser();
		$n		= count( $cid );

		if ($n > 0)
		{
			foreach ($cid as $id)
			{
				if ($table->load( (int)$id ))
				{
					$table->id			= 0;
					$table->nom			= '('.JText::_( 'GMAPFP_COPIE_DE').') ' . $table->nom;
					$table->alias		= '';
					$table->published	= 0;
					$table->created_by	= $user->get('id');
			
					if (!$table->store()) {
						return JFactory::getApplication()->enqueueMessage($table->getError(), 'error');
					}
				}
				else {
					return JFactory::getApplication()->enqueueMessage($table->getError(), 'error');
				}
			}
		}
		else {
			return JFactory::getApplication()->enqueueMessage(JText::_( 'No items selected' ), 'error');
		}
		$table->reorder();
		$this->setMessage( JText::sprintf( 'Items copied', $n ) );
	}
	
	function user()
	{
		if (!JFactory::getUser()->authorise('core.manage', 'com_gmapfp') or !JFactory::getUser()->authorise('core.edit', 'com_gmapfp'))
			return JFactory::getApplication()->enqueueMessage(JText::_('JERROR_ALERTNOAUTHOR'), 'error');

		// Check for request forgeries
		JRequest::checkToken() or jexit( 'Invalid Token' );

		$this->input->set( 'view', 'auteur' );
		$this->input->set( 'layout', 'default'  );
		$this->input->set('hidemainmenu', 1);

		parent::display();
	}
	
	function checkin($recordId = ''){

		$model = $this->getModel('gmapfp');
		$return = true;
		
		if (!$recordId) {
				$recordId = JRequest::getVar( 'cid', null, 'post', 'array' );
				$recordId = $recordId[0];
			} else $return = false;

		if ($model->checkin($recordId) === false)
		{
			// Check-in failed, go back to the record and display a notice.
			$this->setError(JText::sprintf('JLIB_APPLICATION_ERROR_CHECKIN_FAILED', $model->getError()));
			$this->setMessage($this->getError(), 'error');

			$this->setRedirect(JRoute::_('index.php?option=com_gmapfp&controller=gmapfp&task=view', false));

			return false;
		}
		if ($return) $this->setRedirect( 'index.php?option=com_gmapfp&controller=gmapfp&task=view' );
			else return;
	}

	function cancel()
	{
		$model = $this->getModel('gmapfp');
		$recordId = JRequest::getInt('id');

		if ($model->checkin($recordId) === false)
		{
			// Check-in failed, go back to the record and display a notice.
			$this->setError(JText::sprintf('JLIB_APPLICATION_ERROR_CHECKIN_FAILED', $model->getError()));
			$this->setMessage($this->getError(), 'error');

			$this->setRedirect(JRoute::_('index.php?option=com_gmapfp&controller=gmapfp&task=view', false));

			return false;
		}
		$msg = JText::_( 'Operation Cancelled' );
		$this->setRedirect( 'index.php?option=com_gmapfp&controller=gmapfp&task=view', $msg );
	}

	function resethits()
	{
		if (!JFactory::getUser()->authorise('core.manage', 'com_gmapfp') or !JFactory::getUser()->authorise('core.edit', 'com_gmapfp'))
			return JFactory::getApplication()->enqueueMessage(JText::_('JERROR_ALERTNOAUTHOR'), 'error');

		$post	= JRequest::get('post');
		$post['hits'] = 0;
		$model = $this->getModel('gmapfp');
		$returnid=$model->store($post);
		if ($returnid>0) {
			$msg = JText::_( 'Successfully Reset Hit count' );
		} else {
			$msg = JText::_( 'GMAPFP_SAVED_ERROR' );
		}

		$link = 'index.php?option=com_gmapfp&controller=gmapfp&task=edit&cid[]='.(int)$returnid;
		// Check the table in so it can be edited.... we are done with it anyway
		$this->setRedirect($link, $msg);
	}
	
	function file_delete()
	{
		JRequest::checkToken( 'request' ) or jexit( 'Invalid Token' );
		if (!JFactory::getUser()->authorise('core.manage', 'com_gmapfp') or !JFactory::getUser()->authorise('core.edit', 'com_gmapfp'))
			return JFactory::getApplication()->enqueueMessage(JText::_('JERROR_ALERTNOAUTHOR'), 'error');


		// Get some data from the request
		$id 	= (int)JRequest::getVar('cid');
		$files	= JRequest::getVar( 'rm', array(), '', 'array' );
		// Initialize variables
		$ret = 'succes';

		if (count($files)) {
			foreach ($files as $file)
			{
				//efface image
				$fullPath = JPath::clean(COM_GMAPFP_IMAGES_FOLDER.'/GA'.$id.'/'.$file);
				if (is_file($fullPath)) {
					if (!JFile::delete($fullPath)) $ret = 'error';
				}
				//efface miniature
				$fullPath = JPath::clean(COM_GMAPFP_IMAGES_FOLDER.'/GA'.$id.'/thumbs/'.$file);
				if (is_file($fullPath)) {
					if (!JFile::delete($fullPath)) $ret = 'error';
				}
			}
		}
		$link="index.php?option=com_gmapfp&controller=gmapfp&task=galerie&tmpl=component&cid=".$id;
		$this->setRedirect($link, $ret, 'message');
	}

	function file_add_infos()
	{
		JRequest::checkToken( 'request' ) or jexit( 'Invalid Token' );
		if (!JFactory::getUser()->authorise('core.manage', 'com_gmapfp') or !JFactory::getUser()->authorise('core.edit', 'com_gmapfp'))
			return JFactory::getApplication()->enqueueMessage(JText::_('JERROR_ALERTNOAUTHOR'), 'error');

		$config = JComponentHelper::getParams('com_gmapfp');

		// Get some data from the request
 		$post	= JRequest::get('post');

		$ret = JText::_('GMAPFP_SAVED');

		if ($post['id'] and $post['file']) {
			jimport( 'joomla.filesystem.file' );
			jimport( 'joomla.filesystem.folder' );
			
			$folder = JPATH_ROOT.'/images/gmapfp/GA'.$post['id'].'/infos';

			if (!is_dir($folder)){
				JFolder::create($folder);
				$buffer = "<html>\n<body bgcolor=\"#FFFFFF\">\n</body>\n</html>";
				@JFile::write($folder.'/index.html', $buffer);
			}

			$xml_file = substr($post['file'], 0, -(strlen(JFile::getExt($post['file']))+1));
			$xml_file .= '.xml';
			$buffer = "<infos>\n<titre>".htmlspecialchars($post['titre'])."</titre>\n<description>".htmlspecialchars($post['description'])."</description>\n</infos>";
			@JFile::write($folder.'/'.$xml_file, $buffer);
		} else {
			$ret ='def file_add_infos';
		}
		$link="index.php?option=com_gmapfp&controller=gmapfp&task=galerie&tmpl=component&cid=".$post['id'];
		$this->setRedirect($link, $ret, 'message');
	}

	public function saveOrderAjax()
	{
		if (!JFactory::getUser()->authorise('core.manage', 'com_gmapfp') or !JFactory::getUser()->authorise('core.edit', 'com_gmapfp'))
			return JFactory::getApplication()->enqueueMessage(JText::_('JERROR_ALERTNOAUTHOR'), 'error');

		// Get the input
		$pks = $this->input->post->get('cid', array(), 'array');
		$order = $this->input->post->get('order', array(), 'array');

		// Sanitize the input
		JArrayHelper::toInteger($pks);
		JArrayHelper::toInteger($order);

		// Save the ordering
		$model = $this->getModel('gmapfps');
		$return = $model->saveorder($pks, $order);

		if ($return)
		{
			echo "1";
		}

		// Close the application
		JFactory::getApplication()->close();
	}
			
}
?>
